@@ -1,7 +1,11 @@
 #  !/usr/bin/env python
-#   -*- coding: utf-8 -*-
 #
 #  classes.py
+"""
+Classes representing pagesizes.
+
+.. |AnyNumber| replace:: :py:data:`~typing.Union` [:class:`int`, :class:`float`, :class:`~decimal.Decimal`, :class:`~domdf_python_tools.pagesizes.Unit`]
+"""
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
@@ -22,7 +26,7 @@
 #
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 #  GNU Lesser General Public License for more details.
 #
 #  You should have received a copy of the GNU Lesser General Public License
@@ -36,8 +40,10 @@ from collections import namedtuple
 from typing import List, Tuple
 
 # this package
-from ._types import AnyNumber
-from .units import Unit, _rounders, cicero, cm, didot, inch, mm, new_cicero, new_didot, pica, pt, scaled_point, um
+from domdf_python_tools.typing import AnyNumber
+
+# this package
+from .units import Unit, _rounders, cm, inch, mm, pica, pt, um
 from .utils import convert_from
 
 __all__ = [
@@ -47,11 +53,6 @@ __all__ = [
 		"Size_cm",
 		"Size_um",
 		"Size_pica",
-		"Size_didot",
-		"Size_cicero",
-		"Size_new_didot",
-		"Size_new_cicero",
-		"Size_scaled_point",
 		"PageSize",
 		]
 
@@ -61,9 +62,9 @@ class BaseSize(namedtuple("__BaseSize", "width, height")):
 	Base class namedtuple representing a page size, in point
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 	"""
 
 	__slots__: List[str] = []
@@ -85,7 +86,7 @@ class BaseSize(namedtuple("__BaseSize", "width, height")):
 	def from_pt(cls, size: Tuple[float, float]):
 		"""
 		Create a :class:`~domdf_python_tools.pagesizes.classes.BaseSize` object from a
-		page size in point..
+		page size in point.
 
 		:param size: The size, in point, to convert from
 
@@ -162,9 +163,9 @@ class Size_mm(BaseSize):
 	representing a pagesize in millimeters.
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 	"""
 
 	_unit = mm
@@ -176,9 +177,9 @@ class Size_inch(BaseSize):
 	representing a pagesize in inches.
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 	"""
 
 	_unit = inch
@@ -190,9 +191,9 @@ class Size_cm(BaseSize):
 	representing a pagesize in centimeters.
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 	"""
 
 	_unit = cm
@@ -204,9 +205,9 @@ class Size_um(BaseSize):
 	representing a pagesize in micrometers.
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 	"""
 
 	_unit = um
@@ -218,107 +219,53 @@ class Size_pica(BaseSize):
 	representing a pagesize in pica.
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 	"""
 
 	_unit = pica
 
 
-class Size_didot(BaseSize):
-	"""
-	Subclass of :class:`~domdf_python_tools.pagesizes.classes.BaseSize`
-	representing a pagesize in didots / French Points.
-
-	:param width: The page width
-	:type width: int, float, Decimal or Unit
-	:param height: The page height
-	:type height: int, float, Decimal or Unit
-	"""
-
-	_unit = didot
-
-
-class Size_cicero(BaseSize):
-	"""
-	Subclass of :class:`~domdf_python_tools.pagesizes.classes.BaseSize`
-	representing a pagesize in ciceros.
-
-	:param width: The page width
-	:type width: int, float, Decimal or Unit
-	:param height: The page height
-	:type height: int, float, Decimal or Unit
-	"""
-
-	_unit = cicero
-
-
-class Size_new_didot(BaseSize):
-	"""
-	Subclass of :class:`~domdf_python_tools.pagesizes.classes.BaseSize`
-	representing a pagesize in new didots.
-
-	:param width: The page width
-	:type width: int, float, Decimal or Unit
-	:param height: The page height
-	:type height: int, float, Decimal or Unit
-	"""
-
-	_unit = new_didot
-
-
-class Size_new_cicero(BaseSize):
-	"""
-	Subclass of :class:`~domdf_python_tools.pagesizes.classes.BaseSize`
-	representing a pagesize in ciceros.
-
-	:param width: The page width
-	:type width: int, float, Decimal or Unit
-	:param height: The page height
-	:type height: int, float, Decimal or Unit
-	"""
-
-	_unit = new_cicero
-
-
-class Size_scaled_point(BaseSize):
-	"""
-	Subclass of :class:`~domdf_python_tools.pagesizes.classes.BaseSize`
-	representing a pagesize in scaled points.
-
-	:param width: The page width
-	:type width: int, float, Decimal or Unit
-	:param height: The page height
-	:type height: int, float, Decimal or Unit
-	"""
-
-	_unit = scaled_point
-
-
 class PageSize(BaseSize):
 	"""
 	Subclass of :class:`~domdf_python_tools.pagesizes.classes.BaseSize`
 	representing a pagesize in point.
 
 	:param width: The page width
-	:type width: int, float, Decimal or Unit
+	:type width: |AnyNumber|
 	:param height: The page height
-	:type height: int, float, Decimal or Unit
+	:type height: |AnyNumber|
 
 	The pagesize can be converted to other units using the properties below.
 	"""
 
 	__slots__: List[str] = []
 
-	def __new__(cls, width, height, unit=pt):
-		width, height = convert_from((width, height), unit)
+	def __new__(cls, width: AnyNumber, height: AnyNumber, unit: AnyNumber = pt):
+		"""
+		Create a new :class:`~domdf_python_tools.pagesizes.classes.PageSize` object.
+
+		:param width:
+		:param height:
+		:param unit:
+		"""
+
+		width, height = convert_from((width, height), unit)  # type: ignore
 		return super().__new__(cls, width, height)
 
+	@property
+	def pt(self) -> "PageSize":
+		"""
+		Returns the pagesize in pt.
+		"""
+
+		return self
+
 	@property
 	def inch(self) -> Size_inch:
 		"""
-		Returns the pagesize in inches
+		Returns the pagesize in inches.
 		"""
 
 		return Size_inch.from_pt(self)
@@ -326,7 +273,7 @@ class PageSize(BaseSize):
 	@property
 	def cm(self) -> Size_cm:
 		"""
-		Returns the pagesize in centimeters
+		Returns the pagesize in centimeters.
 		"""
 
 		return Size_cm.from_pt(self)
@@ -334,7 +281,7 @@ class PageSize(BaseSize):
 	@property
 	def mm(self) -> Size_mm:
 		"""
-		Returns the pagesize in millimeters
+		Returns the pagesize in millimeters.
 		"""
 
 		return Size_mm.from_pt(self)
@@ -342,67 +289,19 @@ class PageSize(BaseSize):
 	@property
 	def um(self) -> Size_um:
 		"""
-		Returns the pagesize in micrometers
+		Returns the pagesize in micrometers.
 		"""
 
 		return Size_um.from_pt(self)
 
+	µm = um
+
 	@property
 	def pc(self) -> Size_pica:
 		"""
-		Returns the pagesize in pica
+		Returns the pagesize in pica.
 		"""
 
 		return Size_pica.from_pt(self)
 
 	pica = pc
-
-	@property
-	def dd(self) -> Size_didot:
-		"""
-		Returns the pagesize in didots
-		"""
-
-		return Size_didot.from_pt(self)
-
-	didot = dd
-
-	@property
-	def cc(self) -> Size_cicero:
-		"""
-		Returns the pagesize in ciceros
-		"""
-
-		return Size_cicero.from_pt(self)
-
-	cicero = cc
-
-	@property
-	def nd(self) -> Size_new_didot:
-		"""
-		Returns the pagesize in new didots
-		"""
-
-		return Size_new_didot.from_pt(self)
-
-	new_didot = nd
-
-	@property
-	def nc(self) -> Size_new_cicero:
-		"""
-		Returns the pagesize in new ciceros
-		"""
-
-		return Size_new_cicero.from_pt(self)
-
-	new_cicero = nc
-
-	@property
-	def sp(self) -> Size_scaled_point:
-		"""
-		Returns the pagesize in scaled point
-		"""
-
-		return Size_scaled_point.from_pt(self)
-
-	scaled_point = sp
