@@ -35,14 +35,15 @@ Functions for paths and files.
 #
 
 # stdlib
+import json
 import os
 import pathlib
 import shutil
 import stat
-from typing import IO, Any, Callable, Optional
+from typing import IO, Any, Callable, Iterable, List, Optional
 
 # this package
-from domdf_python_tools.typing import PathLike
+from domdf_python_tools.typing import JsonLibrary, PathLike
 
 __all__ = [
 		"append",
@@ -60,6 +61,8 @@ __all__ = [
 		"WindowsPathPlus",
 		]
 
+newline_default = object()
+
 
 def append(var: str, filename: PathLike, **kwargs) -> int:
 	"""
@@ -262,6 +265,9 @@ def clean_writer(string: str, fp: IO) -> None:
 	while buffer[-1:] == ['']:
 		buffer = buffer[:-1]
 
+	if not buffer:
+		fp.write('\n')
+
 	for line in buffer:
 		fp.write(line)
 		fp.write('\n')
@@ -292,6 +298,10 @@ class PathPlus(pathlib.Path):
 	but cannot instantiate a WindowsPath on a POSIX system or vice versa.
 
 	.. versionadded:: 0.3.8
+
+	.. versionchanged:: 0.5.1
+
+		Defaults to Unix line endings (``LF``) on all platforms.
 	"""
 
 	def __new__(cls, *args, **kwargs):
@@ -403,6 +413,26 @@ class PathPlus(pathlib.Path):
 
 		return super().write_text(data, encoding=encoding, errors=errors)
 
+	def write_lines(
+			self,
+			data: Iterable[str],
+			encoding: Optional[str] = "UTF-8",
+			errors: Optional[str] = None,
+			) -> None:
+		"""
+		Open the file in text mode, write the given list of lines to it without trailing spaces,
+		and close the file.
+
+		:param data:
+		:type data: str
+		:param encoding: The encoding to write to the file using.
+		:param errors:
+
+		.. versionadded:: 0.5.0
+		"""
+
+		return self.write_clean("\n".join(data), encoding=encoding, errors=errors)
+
 	def read_text(
 			self,
 			encoding: Optional[str] = "UTF-8",
@@ -421,20 +451,39 @@ class PathPlus(pathlib.Path):
 
 		return super().read_text(encoding=encoding, errors=errors)
 
+	def read_lines(
+			self,
+			encoding: Optional[str] = "UTF-8",
+			errors: Optional[str] = None,
+			) -> List[str]:
+		"""
+		Open the file in text mode, return a list containing the lines in the file,
+		and close the file.
+
+		:param encoding: The encoding to write to the file using.
+		:param errors:
+
+		:return: The content of the file.
+
+		.. versionadded:: 0.5.0
+		"""
+
+		return self.read_text(encoding=encoding, errors=errors).split("\n")
+
 	def open(
 			self,
 			mode: str = "r",
 			buffering: int = -1,
 			encoding: Optional[str] = "UTF-8",
 			errors: Optional[str] = None,
-			newline: Optional[str] = None,
+			newline: Optional[str] = newline_default,  # type: ignore
 			) -> IO[Any]:
 		"""
 		Open the file pointed by this path and return a file object, as
 		the built-in open() function does.
 
 		:param mode: The mode to open the file in.
-		:default mode: ``"r"`` (read only)
+		:default mode: ``'r'`` (read only)
 		:type mode: str
 		:param buffering:
 		:type buffering: int
@@ -442,16 +491,82 @@ class PathPlus(pathlib.Path):
 		:type encoding: str
 		:param errors:
 		:param newline:
+		:default newline: `universal newlines <https://docs.python.org/3/glossary.html#term-universal-newlines>`__ for reading, Unix line endings (``LF``) for writing.
 
 		:return:
 
 		.. versionadded:: 0.3.8
+
+		.. versionchanged:: 0.5.1
+
+			Defaults to Unix line endings (``LF``) on all platforms.
 		"""
 
 		if 'b' in mode:
 			encoding = None
+			newline = None
+
+		if newline is newline_default:
+			if 'r' in mode:
+				newline = None
+			else:
+				newline = "\n"
+
 		return super().open(mode, buffering=buffering, encoding=encoding, errors=errors, newline=newline)
 
+	def dump_json(
+			self,
+			data: Any,
+			encoding: Optional[str] = "UTF-8",
+			errors: Optional[str] = None,
+			json_library: JsonLibrary = json,  # type: ignore
+			**kwargs,
+			) -> int:
+		"""
+		Dump ``data`` to the file as JSON.
+
+		:param data: The object to serialise to JSON.
+		:param encoding: The encoding to write to the file using.
+		:param errors:
+		:param json_library: The JSON serialisation library to use.
+		:default json_library: :mod:`json`
+		:param kwargs: Keyword arguments to pass to the JSON serialisation function.
+
+		.. versionadded:: 0.5.0
+		"""
+
+		return self.write_text(
+				json_library.dumps(data, **kwargs),
+				encoding=encoding,
+				errors=errors,
+				)
+
+	def load_json(
+			self,
+			encoding: Optional[str] = "UTF-8",
+			errors: Optional[str] = None,
+			json_library: JsonLibrary = json,  # type: ignore
+			**kwargs,
+			) -> Any:
+		"""
+		Load JSON data from the file.
+
+		:param encoding: The encoding to write to the file using.
+		:param errors:
+		:param json_library: The JSON serialisation library to use.
+		:default json_library: :mod:`json`
+		:param kwargs: Keyword arguments to pass to the JSON deserialisation function.
+
+		:return: The deserialised JSON data.
+
+		.. versionadded:: 0.5.0
+		"""
+
+		return json_library.loads(
+				self.read_text(encoding=encoding, errors=errors),
+				**kwargs,
+				)
+
 
 class PosixPathPlus(PathPlus, pathlib.PurePosixPath):
 	"""Path subclass for non-Windows systems.
